# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails from dynamically allocated email addresses. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.   ## Resources - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://www.mailslurp.com/docs/) - [Examples](https://github.com/mailslurp/examples) repository   # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.alias_controller_api import AliasControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestAliasControllerApi(unittest.TestCase):
    """AliasControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.alias_controller_api.AliasControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_alias(self):
        """Test case for create_alias

        Create an email alias  # noqa: E501
        """
        pass

    def test_create_anonymous_alias(self):
        """Test case for create_anonymous_alias

        Create an anonymous email alias  # noqa: E501
        """
        pass

    def test_delete_alias(self):
        """Test case for delete_alias

        Delete an owned alias  # noqa: E501
        """
        pass

    def test_get_alias(self):
        """Test case for get_alias

        Get an email alias  # noqa: E501
        """
        pass

    def test_get_aliases(self):
        """Test case for get_aliases

        Get all email aliases  # noqa: E501
        """
        pass

    def test_update_alias(self):
        """Test case for update_alias

        Update an owned alias  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
